import Dialog from './Dialog'

import { use, registerComponent, registerComponentProgrammatic } from '../../utils/plugins'
import { merge } from '../../utils/helpers'

let localVueInstance

function open(propsData) {
  const vm = typeof window !== 'undefined' && window.Vue ? window.Vue : localVueInstance
  const DialogComponent = vm.extend(Dialog)
  const component = new DialogComponent({
    el: document.createElement('div'),
    propsData
  })

  return new Promise((resolve, reject) => {
    component.$on('confirm', resolve)
    component.$on('cancel', reject)
  })
}

const DialogProgrammatic = {
  alert(params) {
    if (typeof params === 'string') {
      params = {
        message: params
      }
    }
    const defaultParam = {
      canCancel: false
    }
    const propsData = merge(defaultParam, params)
    return open(propsData)
  },
  confirm(params) {
    const defaultParam = {}
    const propsData = merge(defaultParam, params)
    return open(propsData)
  },
}

const Plugin = {
  install(Vue) {
    localVueInstance = Vue
    registerComponent(Vue, Dialog)
    registerComponentProgrammatic(Vue, 'dialog', DialogProgrammatic)
  }
}

use(Plugin)

export default Plugin

export {
  DialogProgrammatic,
  Dialog as PDialog
}
